pub fn border_radius(variant: &ThemeVariant) -> f32Expand description
Returns the standard border radius from geometry, defaulting to 4.0.
pub fn border_radius(variant: &ThemeVariant) -> f32Returns the standard border radius from geometry, defaulting to 4.0.