pub fn button_padding(resolved: &ResolvedThemeVariant) -> PaddingExpand description
Returns button padding from the resolved theme as an iced Padding.
Maps padding_vertical to top/bottom and padding_horizontal to left/right.
pub fn button_padding(resolved: &ResolvedThemeVariant) -> PaddingReturns button padding from the resolved theme as an iced Padding.
Maps padding_vertical to top/bottom and padding_horizontal to left/right.