pub fn input_padding(resolved: &ResolvedThemeVariant) -> PaddingExpand description
Returns text input padding from the resolved theme as an iced Padding.
Maps padding_vertical to top/bottom and padding_horizontal to left/right.
pub fn input_padding(resolved: &ResolvedThemeVariant) -> PaddingReturns text input padding from the resolved theme as an iced Padding.
Maps padding_vertical to top/bottom and padding_horizontal to left/right.