pub fn selection_color(resolved: &ResolvedThemeVariant) -> ColorExpand description
Returns the selection highlight background color from the resolved theme.
pub fn selection_color(resolved: &ResolvedThemeVariant) -> ColorReturns the selection highlight background color from the resolved theme.